@@ -6,19 +6,19 @@ from cli.models import DocumentDetections
 
 class ResultsPrinter:
     printers = {
-        'text': TextPrinter(),
-        'json': JsonPrinter()
+        'text': TextPrinter,
+        'json': JsonPrinter
     }
 
     def print_results(self, context: click.Context, detections_results_list: List[DocumentDetections],
                       output_type: str):
-        printer = self.get_printer(output_type)
-        printer.print_results(context, detections_results_list)
+        printer = self.get_printer(output_type, context)
+        printer.print_results(detections_results_list)
 
-    def get_printer(self, output_type: str):
+    def get_printer(self, output_type: str, context: click.Context):
         printer = self.printers.get(output_type)
         if not printer:
             raise ValueError(f'the provided output is not supported - {output_type}')
 
-        return printer
+        return printer(context)
 
