@@ -11,7 +11,7 @@ class InMemoryZip(object):
 
     def append(self, filename, unique_id, content):
         # Write the file to the in-memory zip
-        filename = filename if unique_id is None else os.path.join(unique_id, filename)
+        filename = filename if unique_id is None else concat_unique_id(filename, unique_id)
         self.zip.writestr(filename, content)
 
     def close(self):
@@ -23,4 +23,5 @@ class InMemoryZip(object):
         return self.in_memory_zip.read()
 
 
-
+def concat_unique_id(filename: str, unique_id: str) -> str:
+    return f'{unique_id}{filename}' if filename.startswith(os.sep) else os.path.join(unique_id, filename)
