@@ -1,4 +1,4 @@
-from typing import List, Dict
+from typing import List, Dict, Optional
 from marshmallow import Schema, fields, EXCLUDE, post_load
 
 
@@ -35,10 +35,11 @@ class DetectionSchema(Schema):
 
 
 class DetectionsPerFile(Schema):
-    def __init__(self, file_name: str, detections: List[Detection]):
+    def __init__(self, file_name: str, detections: List[Detection], commit_id: Optional[str] = None):
         super().__init__()
         self.file_name = file_name
         self.detections = detections
+        self.commit_id = commit_id
 
 
 class DetectionsPerFileSchema(Schema):
@@ -47,6 +48,7 @@ class DetectionsPerFileSchema(Schema):
 
     file_name = fields.String()
     detections = fields.List(fields.Nested(DetectionSchema))
+    commit_id = fields.String(allow_none=True)
 
     @post_load
     def build_dto(self, data, **kwargs):
@@ -54,12 +56,13 @@ class DetectionsPerFileSchema(Schema):
 
 
 class ZippedFileScanResult(Schema):
-    def __init__(self, did_detect: bool, detections_per_file: List[DetectionsPerFile], scan_id: str = None,
-                 err: str = None):
+    def __init__(self, did_detect: bool, detections_per_file: List[DetectionsPerFile], report_url: Optional[str] = None,
+                 scan_id: str = None, err: str = None):
         super().__init__()
         self.did_detect = did_detect
         self.detections_per_file = detections_per_file
         self.scan_id = scan_id
+        self.report_url = report_url
         self.err = err
 
 
@@ -69,6 +72,7 @@ class ZippedFileScanResultSchema(Schema):
 
     did_detect = fields.Boolean()
     scan_id = fields.String()
+    report_url = fields.String(allow_none=True)
     detections_per_file = fields.List(
         fields.Nested(DetectionsPerFileSchema))
     err = fields.String()
@@ -102,6 +106,51 @@ class ScanResultSchema(Schema):
         return ScanResult(**data)
 
 
+class ScanInitializationResponse(Schema):
+    def __init__(self, scan_id: str = None, err: str = None):
+        super().__init__()
+        self.scan_id = scan_id
+        self.err = err
+
+
+class ScanInitializationResponseSchema(Schema):
+    class Meta:
+        unknown = EXCLUDE
+
+    scan_id = fields.String()
+    err = fields.String()
+
+    @post_load
+    def build_dto(self, data, **kwargs):
+        return ScanInitializationResponse(**data)
+
+
+class ScanDetailsResponse(Schema):
+    def __init__(self, scan_status: str = None, results_count: int = None, metadata: str = None, message: str = None,
+                 err: str = None):
+        super().__init__()
+        self.scan_status = scan_status
+        self.detections_count = results_count
+        self.metadata = metadata
+        self.message = message
+        self.err = err
+
+
+class ScanDetailsResponseSchema(Schema):
+    class Meta:
+        unknown = EXCLUDE
+
+    scan_status = fields.String()
+    results_count = fields.Integer(allow_none=True)
+    metadata = fields.String(allow_none=True)
+    message = fields.String(allow_none=True)
+    err = fields.String()
+
+    @post_load
+    def build_dto(self, data, **kwargs):
+        return ScanDetailsResponse(**data)
+
+
 class K8SResource:
     def __init__(self, name: str, resource_type: str, namespace: str, content: Dict):
         super().__init__()
@@ -224,4 +273,4 @@ class ApiTokenGenerationPollingResponseSchema(Schema):
 
     @post_load
     def build_dto(self, data, **kwargs):
-        return ApiTokenGenerationPollingResponse(**data)
\ No newline at end of file
+        return ApiTokenGenerationPollingResponse(**data)
